@@ -56,15 +56,21 @@ UBX_CONFIG_CATEGORIES = [
     "CFG_LOGFILTER",
     "CFG_MOT",
     "CFG_MSGOUT",
+    "CFG_NAVHPG",
     "CFG_NAVSPG",
     "CFG_NMEA",
     "CFG_ODO",
     "CFG_PM",
+    "CFG_PMP",
     "CFG_QZSS",
     "CFG_RATE",
     "CFG_RINV",
+    "CFG_RTCM",
     "CFG_SBAS",
     "CFG_SEC",
+    "CFG_SFCORE",
+    "CFG_SFIMU",
+    "CFG_SFODO",
     "CFG_SIGNAL",
     "CFG_SPI",
     "CFG_TMODE",
